@@ -43,8 +43,8 @@ LOGGER = logging.getLogger('nipype.workflow')
 
 def init_qsiprep_wf(
         subject_list, run_uuid, work_dir, output_dir, bids_dir, ignore, debug, low_mem, anat_only,
-        longitudinal, b0_threshold, hires, denoise_before_combining, dwi_denoise_window,
-        unringing_method, dwi_no_biascorr, no_b0_harmonization, output_resolution,
+        dwi_only, longitudinal, b0_threshold, hires, denoise_before_combining, dwi_denoise_window,
+        unringing_method, dwi_no_biascorr, no_b0_harmonization, output_resolution, infant_mode,
         combine_all_dwis, distortion_group_merge, omp_nthreads, force_spatial_normalization,
         skull_strip_template, skull_strip_fixed_seed, freesurfer, hmc_model,
         impute_slice_threshold, hmc_transform, shoreline_iters, eddy_config, write_local_bvecs,
@@ -70,6 +70,7 @@ def init_qsiprep_wf(
                               ignore=[],
                               debug=False,
                               low_mem=False,
+                              dwi_only=False,
                               anat_only=False,
                               longitudinal=False,
                               b0_threshold=100,
@@ -94,6 +95,7 @@ def init_qsiprep_wf(
                               intramodal_template_iters=0,
                               intramodal_template_transform="Rigid",
                               hmc_transform='Affine',
+                              infant_mode=False,
                               eddy_config=None,
                               shoreline_iters=2,
                               impute_slice_threshold=0,
@@ -126,9 +128,13 @@ def init_qsiprep_wf(
             Write uncompressed .nii files in some cases to reduce memory usage
         anat_only : bool
             Disable diffusion workflows
+        dwi_only : bool
+            Disable the anatomical (T1w/T2w) workflows
         longitudinal : bool
             Treat multiple sessions as longitudinal (may increase runtime)
             See sub-workflows for specific differences
+        infant_mode : bool
+            Run the pipeline for infant DWIs
         b0_threshold : int
             Images with b-values less than this value will be treated as a b=0 image.
         dwi_denoise_window : int
@@ -232,8 +238,10 @@ def init_qsiprep_wf(
             unringing_method=unringing_method,
             dwi_no_biascorr=dwi_no_biascorr,
             no_b0_harmonization=no_b0_harmonization,
+            dwi_only=dwi_only,
             anat_only=anat_only,
             longitudinal=longitudinal,
+            infant_mode=infant_mode,
             b0_threshold=b0_threshold,
             freesurfer=freesurfer,
             hires=hires,
@@ -275,8 +283,8 @@ def init_qsiprep_wf(
 
 def init_single_subject_wf(
         subject_id, name, reportlets_dir, output_dir, bids_dir, ignore, debug, write_local_bvecs,
-        low_mem, anat_only, longitudinal, b0_threshold, denoise_before_combining,
-        dwi_denoise_window, unringing_method, dwi_no_biascorr, no_b0_harmonization,
+        low_mem, dwi_only, anat_only, longitudinal, b0_threshold, denoise_before_combining,
+        dwi_denoise_window, unringing_method, dwi_no_biascorr, no_b0_harmonization, infant_mode,
         combine_all_dwis, distortion_group_merge, omp_nthreads, skull_strip_template,
         force_spatial_normalization, skull_strip_fixed_seed, freesurfer, hires, output_spaces,
         template, output_resolution, prefer_dedicated_fmaps, motion_corr_to, b0_to_t1w_transform,
@@ -314,6 +322,7 @@ def init_single_subject_wf(
             unringing_method='mrdegibbs',
             dwi_no_biascorr=False,
             no_b0_harmonization=False,
+            dwi_only=False,
             anat_only=False,
             longitudinal=False,
             b0_threshold=100,
@@ -336,6 +345,7 @@ def init_single_subject_wf(
             hmc_transform='Affine',
             eddy_config=None,
             shoreline_iters=2,
+            infant_mode=False,
             impute_slice_threshold=0.0,
             write_local_bvecs=False,
             fmap_bspline=False,
@@ -357,6 +367,8 @@ def init_single_subject_wf(
             Write uncompressed .nii files in some cases to reduce memory usage
         anat_only : bool
             Disable functional workflows
+        dwi_only : bool
+            Disable anatomical workflows
         longitudinal : bool
             Treat multiple sessions as longitudinal (may increase runtime)
             See sub-workflows for specific differences
@@ -458,14 +470,18 @@ def init_single_subject_wf(
     else:
         subject_data, layout = collect_data(bids_dir, subject_id)
 
+    if anat_only and dwi_only:
+        raise Exception("--anat-only and --dwi-only are mutually exclusive.")
+
     # Make sure we always go through these two checks
     if not anat_only and subject_data['dwi'] == []:
         raise Exception("No dwi images found for participant {}. "
-                        "All workflows require dwi images.".format(subject_id))
+                        "All workflows require dwi images unless "
+                        "--anat-only is specified.".format(subject_id))
 
-    if not subject_data['t1w']:
+    if not dwi_only and not subject_data['t1w']:
         raise Exception("No T1w images found for participant {}. "
-                        "All workflows require T1w images.".format(subject_id))
+                        "To bypass T1w processing choose --dwi-only.".format(subject_id))
 
     workflow = Workflow(name=name)
     workflow.__desc__ = """
@@ -496,7 +512,8 @@ to workflows in *QSIPrep*'s documentation]\
         niu.IdentityInterface(fields=['subjects_dir']), name='inputnode')
 
     bidssrc = pe.Node(
-        BIDSDataGrabber(subject_data=subject_data, anat_only=anat_only),
+        BIDSDataGrabber(
+            subject_data=subject_data, dwi_only=dwi_only, anat_only=anat_only),
         name='bidssrc')
 
     bids_info = pe.Node(
@@ -525,6 +542,8 @@ to workflows in *QSIPrep*'s documentation]\
     # Preprocessing of T1w (includes registration to MNI)
     anat_preproc_wf = init_anat_preproc_wf(
         name="anat_preproc_wf",
+        dwi_only=dwi_only,
+        infant_mode=infant_mode,
         skull_strip_template=skull_strip_template,
         skull_strip_fixed_seed=skull_strip_fixed_seed,
         output_spaces=output_spaces,
@@ -662,6 +681,7 @@ to workflows in *QSIPrep*'s documentation]\
         output_wfname = output_fname.replace('-', '_')
         dwi_preproc_wf = init_dwi_preproc_wf(
             scan_groups=dwi_info,
+            dwi_only=dwi_only,
             output_prefix=output_fname,
             layout=layout,
             ignore=ignore,
@@ -755,7 +775,6 @@ to workflows in *QSIPrep*'s documentation]\
                      'inputnode.t1_2_mni_reverse_transform'),
                     ('outputnode.dwi_sampling_grid',
                      'inputnode.dwi_sampling_grid'),
-                    ('outputnode.mni_mask', 'inputnode.mni_mask'),
                     # Undefined if --no-freesurfer, but this is safe
                     ('outputnode.subjects_dir', 'inputnode.subjects_dir'),
                     ('outputnode.subject_id', 'inputnode.subject_id'),
